@@ -2,7 +2,7 @@ from typing import Any, Iterable
 from warnings import warn
 
 
-def listify(x: Any):
+def _listify(x: Any):
     """Convert value to list if it is not already iterable."""
     if not isinstance(x, Iterable):
         return [x]
